==> glpk-1.1.1.tar.gz: glpk-1.1.1/glpgel/delete_lu.c <==
/* glpgel/delete_lu.c */

/*----------------------------------------------------------------------
-- This file is a part of the GNU LPK package.
--
-- Copyright (C) 2000 Andrew Makhorin <mao@mai2.rcnet.ru>,
--                    Department for Applied Informatics,
--                    Moscow Aviation Institute, Moscow, Russia.
--                    All rights reserved.
--
-- This code is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This software is distributed "as is" in the hope that it will be
-- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-- General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
----------------------------------------------------------------------*/

#include "glpgel.h"
#include "glpset.h"

/*----------------------------------------------------------------------
-- delete_lu - delete LU-factorization.
--
-- *Synopsis*
--
-- #include "glpgel.h"
-- void delete_lu(LU *lu);
--
-- *Description*
--
-- The delete_lu routine deletes the LU-factorization which lu points
-- to freeing all memory allocated to this object. */

void delete_lu(LU *lu)
{     delete_per(lu->P);
      delete_mat(lu->L);
      delete_mat(lu->U);
      delete_per(lu->Q);
      ufree(lu);
      return;
}

/* eof */

==> glpk-3.0.3.tar.gz: glpk-3.0.3/glpgel/delete_lu.c <==
/* glpgel/delete_lu.c */

/*----------------------------------------------------------------------
-- This file is a part of the GLPK package.
--
-- Copyright (C) 2000, 2001 Andrew Makhorin <mao@mai2.rcnet.ru>,
--                          Department for Applied Informatics,
--                          Moscow Aviation Institute, Moscow, Russia.
--                          All rights reserved.
--
-- This code is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This software is distributed "as is" in the hope that it will be
-- useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-- of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-- General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
----------------------------------------------------------------------*/

#include "glpgel.h"
#include "glpset.h"

/*----------------------------------------------------------------------
-- delete_lu - delete LU-factorization.
--
-- *Synopsis*
--
-- #include "glpgel.h"
-- void delete_lu(LU *lu);
--
-- *Description*
--
-- The delete_lu routine deletes the LU-factorization, which lu points
-- to, freeing all memory allocated to this object. */

void delete_lu(LU *lu)
{     delete_per(lu->P);
      delete_mat(lu->L);
      delete_mat(lu->U);
      delete_per(lu->Q);
      ufree(lu);
      return;
}

/* eof */
